==> ModuleXtender-1.5.1.zip: ModuleXtender/action.manageLinks.php <==
<?php
if (!isset($gCms)) exit;

/* -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

   Code for ModuleXtender admin action
   
   -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
   
  This code is aimed to upload and/or display files
   
*/

if (isset($params['link_id']) && $params['link_id'] != '')
{
	$link = MX_Link::retrieveByPk($params['link_id']);
}
else 
{
	$link = new MX_Link();
}

$link->Populate($params); 
// UPDATE PART
 
// Related categories
$categories = MX_RelatedCategory::doSelect(array('where' => array(
'modulename' => ($link->getModuleName() != '')?$link->getModuleName():$params['module_name'], 
'type' => 'links')));

if (isset($params['is_submitted']))
{	
	
  $link->save();      
  
  $old_document = $link;
      
  $link = new MX_Link();
}

if (isset($params['is_submitted'])  && isset($old_document) && $old_document->getId() != '')
{
    foreach ($categories as $category)
    {
     if (isset($params['MX_category_'.$category->getId()]))
      {
        $existing_items = MX_RelationLink::doSelect(array('where' => array(
          'modulename' => 'MX_' . $category->getType(),
          'module_id' => $old_document->getId(),
          'rel_code' => 'related_category_' . $category->getId(),
        )));
        
        foreach ($existing_items as $item)
        {
          $item->delete();
        }
          $relation = new MX_RelationLink();
          $relation->setRightModule('MX_' . $category->getType());
          $relation->setRightModuleId($old_document->getId());
          $relation->setLeftModule('related_category_'.$category->getId());
          $relation->setLeftModuleId($params['MX_category_'.$category->getId()]);
          $relation->save();
          
      }
    }  
    
  echo $this->javascripts->call();
  echo $this->javascripts->getJSCallFromiFrame($params['js_call']);
}

// FORM PART

$this->smarty->assign('form_start',$this->CreateFormStart($id, 'manageLinks', $returnid, 'post'));

$this->smarty->assign('disable_theme',$this->CreateInputHidden($id, 'disable_theme', 'true'));
$this->smarty->assign('is_submitted',$this->CreateInputHidden($id, 'is_submitted', true));

$this->smarty->assign('module_name',$this->CreateInputHidden($id, 'module_name', ($link->getModuleName() != '')?$link->getModuleName():$params['module_name']));
$this->smarty->assign('link_id',$this->CreateInputHidden($id, 'link_id', ($link->getId() != '')?$link->getId():''));
$this->smarty->assign('module_id',$this->CreateInputHidden($id, 'module_id', ($link->getModuleId() != '')?$link->getModuleId():$params['module_id']));
$this->smarty->assign('js_call',$this->CreateInputHidden($id, 'js_call', isset($params['js_call'])?$params['js_call']:''));

$this->smarty->assign('title_link_title', $this->Lang('title'));
$this->smarty->assign('title_link_url', $this->Lang('url'));

$this->smarty->assign('link_title',$this->CreateInputText($id, 'title', $link->getTitle(), 50));
$this->smarty->assign('link_url', $this->CreateInputText($id, 'url', $link->getUrl(), 50));

foreach ($categories as $category)
{ 
  $category->input = MC_CreateInputSelectList($id, 'MX_category_' . $category->getId(), 
     array('')+$category->getCategory()->getOptionsById(),
     array($category->checkRelation($link->getId())),
      1, '', false );      
}

$this->smarty->assign('categories', $categories);

$this->smarty->assign('upload', $this->Lang('upload'));

echo $this->ProcessTemplate('admin.manageLinks.tpl');

==> ModuleXtender-1.6.1.zip: ModuleXtender/action.manageLinks.php <==
<?php
if (!isset($gCms)) exit;

/* -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

   Code for ModuleXtender admin action
   
   -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
   
  This code is aimed to upload and/or display files
   
*/

if (isset($params['link_id']) && $params['link_id'] != '')
{
	$link = MX_Link::retrieveByPk($params['link_id']);
}
else 
{
	$link = new MX_Link();
}

$link->Populate($params); 
// UPDATE PART
 
// Related categories
$categories = MX_RelatedCategory::doSelect(array('where' => array(
'modulename' => ($link->getModuleName() != '')?$link->getModuleName():$params['module_name'], 
'type' => 'links')));

if (isset($params['is_submitted']))
{	
	
  $link->save();      
  
  $old_document = $link;
      
  $link = new MX_Link();
}

if (isset($params['is_submitted'])  && isset($old_document) && $old_document->getId() != '')
{
    foreach ($categories as $category)
    {
     if (isset($params['MX_category_'.$category->getId()]))
      {
        $existing_items = MX_RelationLink::doSelect(array('where' => array(
          'modulename' => 'MX_' . $category->getType(),
          'module_id' => $old_document->getId(),
          'rel_code' => 'related_category_' . $category->getId(),
        )));
        
        foreach ($existing_items as $item)
        {
          $item->delete();
        }
          $relation = new MX_RelationLink();
          $relation->setRightModule('MX_' . $category->getType());
          $relation->setRightModuleId($old_document->getId());
          $relation->setLeftModule('related_category_'.$category->getId());
          $relation->setLeftModuleId($params['MX_category_'.$category->getId()]);
          $relation->save();
          
      }
    }  
    
	// We want to inform the main module that we have proceeded an update
    
	if (isset($gCms->modules[$old_document->getModuleName()]) && is_object($gCms->modules[$old_document->getModuleName()]['object']))
	{
		$main_module =& $gCms->modules[$old_document->getModuleName()]['object'];
		if (method_exists($main_module, 'updateItem'))
		{
			$main_module->updateItem($old_document->getModuleId());
		}
	}


  echo $this->javascripts->call();
  echo $this->javascripts->getJSCallFromiFrame($params['js_call']);
}

// FORM PART

$this->smarty->assign('form_start',$this->CreateFormStart($id, 'manageLinks', $returnid, 'post'));

$this->smarty->assign('disable_theme',$this->CreateInputHidden($id, 'disable_theme', 'true'));
$this->smarty->assign('is_submitted',$this->CreateInputHidden($id, 'is_submitted', true));

$this->smarty->assign('module_name',$this->CreateInputHidden($id, 'module_name', ($link->getModuleName() != '')?$link->getModuleName():$params['module_name']));
$this->smarty->assign('link_id',$this->CreateInputHidden($id, 'link_id', ($link->getId() != '')?$link->getId():''));
$this->smarty->assign('module_id',$this->CreateInputHidden($id, 'module_id', ($link->getModuleId() != '')?$link->getModuleId():$params['module_id']));
$this->smarty->assign('js_call',$this->CreateInputHidden($id, 'js_call', isset($params['js_call'])?$params['js_call']:''));

$this->smarty->assign('title_link_title', $this->Lang('title'));
$this->smarty->assign('title_link_url', $this->Lang('url'));

$this->smarty->assign('link_title',$this->CreateInputText($id, 'title', $link->getTitle(), 50));
$this->smarty->assign('link_url', $this->CreateInputText($id, 'url', $link->getUrl(), 50));

foreach ($categories as $category)
{ 
  $category->input = MC_CreateInputSelectList($id, 'MX_category_' . $category->getId(), 
     array('')+$category->getCategory()->getOptionsById(),
     array($category->checkRelation($link->getId())),
      1, '', false );      
}

$this->smarty->assign('categories', $categories);

$this->smarty->assign('upload', $this->Lang('upload'));

echo $this->ProcessTemplate('admin.manageLinks.tpl');
